@@ -173,10 +173,12 @@ void KShortcutsEditor::clearConfiguration()
 }
 
 
+#ifndef KDE_NO_DEPRECATED
 void KShortcutsEditor::importConfiguration( KConfig *config)
 {
     d->importConfiguration(config);
 }
+#endif
 
 
 void KShortcutsEditor::importConfiguration( KConfigBase *config)
@@ -185,10 +187,12 @@ void KShortcutsEditor::importConfiguration( KConfigBase *config)
 }
 
 
+#ifndef KDE_NO_DEPRECATED
 void KShortcutsEditor::exportConfiguration( KConfig *config) const
 {
     exportConfiguration(static_cast<KConfigBase*>(config));
 }
+#endif
 
 
 void KShortcutsEditor::exportConfiguration( KConfigBase *config) const
@@ -319,11 +323,11 @@ void KShortcutsEditorPrivate::initGUI( KShortcutsEditor::ActionTypes types, KSho
     ui.list->setAlternatingRowColors(true);
 
     //TODO listen to changes to global shortcuts
-    QObject::connect(delegate, SIGNAL(shortcutChanged(QVariant, const QModelIndex &)),
-                     q, SLOT(capturedShortcut(QVariant, const QModelIndex &)));
+    QObject::connect(delegate, SIGNAL(shortcutChanged(QVariant,QModelIndex)),
+                     q, SLOT(capturedShortcut(QVariant,QModelIndex)));
     //hide the editor widget chen its item becomes hidden
-    QObject::connect(ui.searchFilter->searchLine(), SIGNAL(hiddenChanged(QTreeWidgetItem *, bool)),
-                     delegate, SLOT(hiddenBySearchLine(QTreeWidgetItem *, bool)));
+    QObject::connect(ui.searchFilter->searchLine(), SIGNAL(hiddenChanged(QTreeWidgetItem*,bool)),
+                     delegate, SLOT(hiddenBySearchLine(QTreeWidgetItem*,bool)));
 
     ui.searchFilter->setFocus();
 }
@@ -613,6 +617,8 @@ more important things):
 */
 void KShortcutsEditorPrivate::printShortcuts() const
 {
+// One cant print on wince
+#ifndef _WIN32_WCE
     QTreeWidgetItem* root = ui.list->invisibleRootItem();
     QTextDocument doc;
     doc.setDefaultFont(KGlobalSettings::generalFont());
@@ -716,6 +722,7 @@ void KShortcutsEditorPrivate::printShortcuts() const
         doc.print(&printer);
     }
     delete dlg;
+#endif
 }
 
 #include "kshortcutseditor.moc"
