@@ -185,7 +185,7 @@ void KFilePlacesModelTest::testReparse()
 
     // reparse the bookmark file
 
-    const QString file = KStandardDirs::locateLocal("data", "kfileplaces/bookmarks.xml");
+    const QString file = KStandardDirs().localxdgdatadir() + "user-places.xbel";
     KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(file, "kfilePlaces");
 
     bookmarkManager->notifyCompleteChange(QString());
@@ -208,7 +208,7 @@ void KFilePlacesModelTest::testReparse()
 
 void KFilePlacesModelTest::testInternalBookmarksHaveIds()
 {
-    const QString file = KStandardDirs::locateLocal("data", "kfileplaces/bookmarks.xml");
+    const QString file = KStandardDirs().localxdgdatadir() + "user-places.xbel";
     KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(file, "kfilePlaces");
     KBookmarkGroup root = bookmarkManager->root();
 
@@ -314,7 +314,7 @@ void KFilePlacesModelTest::testMove()
     QSignalSpy spy_inserted(m_places, SIGNAL(rowsInserted(QModelIndex,int,int)));
     QSignalSpy spy_removed(m_places, SIGNAL(rowsRemoved(QModelIndex,int,int)));
 
-    const QString file = KStandardDirs::locateLocal("data", "kfileplaces/bookmarks.xml");
+    const QString file = KStandardDirs().localxdgdatadir() + "user-places.xbel";
     KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(file, "kfilePlaces");
     KBookmarkGroup root = bookmarkManager->root();
     KBookmark trash = m_places->bookmarkForIndex(m_places->index(3, 0));
@@ -384,6 +384,10 @@ void KFilePlacesModelTest::testMove()
 void KFilePlacesModelTest::testDragAndDrop()
 {
     QList<QVariant> args;
+    QSignalSpy spy_moved(m_places, SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)));
+
+    // Monitor rowsInserted() and rowsRemoved() to ensure they are never emitted:
+    // Moving with drag and drop is expected to emit rowsMoved()
     QSignalSpy spy_inserted(m_places, SIGNAL(rowsInserted(QModelIndex,int,int)));
     QSignalSpy spy_removed(m_places, SIGNAL(rowsRemoved(QModelIndex,int,int)));
 
@@ -397,15 +401,15 @@ void KFilePlacesModelTest::testDragAndDrop()
     urls << KUser().homeDir() << "remote:/" << KDE_ROOT_PATH
          << "/media/cdrom" << "/media/floppy0" << "/foreign" << "/media/nfs" << "/media/XO-Y4" << "trash:/";
     CHECK_PLACES_URLS(urls);
-    args = spy_inserted.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
-    QCOMPARE(args.at(1).toInt(), 8);
-    QCOMPARE(args.at(2).toInt(), 8);
-    QCOMPARE(spy_removed.count(), 1);
-    args = spy_removed.takeFirst();
+    QCOMPARE(spy_inserted.count(), 0);
+    QCOMPARE(spy_removed.count(), 0);
+    QCOMPARE(spy_moved.count(), 1);
+    args = spy_moved.takeFirst();
     QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 3);
     QCOMPARE(args.at(2).toInt(), 3);
+    QCOMPARE(args.at(3).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(4).toInt(), 9);
 
     // Move the trash at the beginning of the list
     indexes.clear();
@@ -417,16 +421,15 @@ void KFilePlacesModelTest::testDragAndDrop()
     urls << "trash:/" << KUser().homeDir() << "remote:/" << KDE_ROOT_PATH
          << "/media/cdrom" << "/media/floppy0" << "/foreign" << "/media/nfs" << "/media/XO-Y4";
     CHECK_PLACES_URLS(urls);
-    QCOMPARE(spy_inserted.count(), 1);
-    args = spy_inserted.takeFirst();
+    QCOMPARE(spy_inserted.count(), 0);
+    QCOMPARE(spy_removed.count(), 0);
+    QCOMPARE(spy_moved.count(), 1);
+    args = spy_moved.takeFirst();
     QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
-    QCOMPARE(args.at(1).toInt(), 0);
-    QCOMPARE(args.at(2).toInt(), 0);
-    QCOMPARE(spy_removed.count(), 1);
-    args = spy_removed.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
-    QCOMPARE(args.at(1).toInt(), 9);
-    QCOMPARE(args.at(2).toInt(), 9);
+    QCOMPARE(args.at(1).toInt(), 8);
+    QCOMPARE(args.at(2).toInt(), 8);
+    QCOMPARE(args.at(3).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(4).toInt(), 0);
 
     // Move the trash in the list (at its original place)
     indexes.clear();
@@ -438,16 +441,15 @@ void KFilePlacesModelTest::testDragAndDrop()
     urls << KUser().homeDir() << "remote:/" << KDE_ROOT_PATH << "trash:/"
          << "/media/cdrom" << "/media/floppy0" << "/foreign" << "/media/nfs" << "/media/XO-Y4";
     CHECK_PLACES_URLS(urls);
-    QCOMPARE(spy_inserted.count(), 1);
-    args = spy_inserted.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
-    QCOMPARE(args.at(1).toInt(), 3);
-    QCOMPARE(args.at(2).toInt(), 3);
-    QCOMPARE(spy_removed.count(), 1);
-    args = spy_removed.takeFirst();
+    QCOMPARE(spy_inserted.count(), 0);
+    QCOMPARE(spy_removed.count(), 0);
+    QCOMPARE(spy_moved.count(), 1);
+    args = spy_moved.takeFirst();
     QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 0);
     QCOMPARE(args.at(2).toInt(), 0);
+    QCOMPARE(args.at(3).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(4).toInt(), 4);
 
     // Dropping on an item is not allowed
     indexes.clear();
@@ -457,6 +459,7 @@ void KFilePlacesModelTest::testDragAndDrop()
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 0);
     QCOMPARE(spy_removed.count(), 0);
+    QCOMPARE(spy_moved.count(), 0);
 }
 
 void KFilePlacesModelTest::testPlacesLifecycle()
@@ -481,7 +484,7 @@ void KFilePlacesModelTest::testPlacesLifecycle()
     QCOMPARE(spy_removed.count(), 0);
 
 
-    const QString file = KStandardDirs::locateLocal("data", "kfileplaces/bookmarks.xml");
+    const QString file = KStandardDirs().localxdgdatadir() + "user-places.xbel";
     KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(file, "kfilePlaces");
     KBookmarkGroup root = bookmarkManager->root();
     KBookmark before_trash = m_places->bookmarkForIndex(m_places->index(2, 0));
@@ -597,7 +600,7 @@ void KFilePlacesModelTest::testDevicePlugging()
 
     // Move the device in the list, and check that it memorizes the position across plug/unplug
 
-    const QString file = KStandardDirs::locateLocal("data", "kfileplaces/bookmarks.xml");
+    const QString file = KStandardDirs().localxdgdatadir() + "user-places.xbel";
     KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(file, "kfilePlaces");
     KBookmarkGroup root = bookmarkManager->root();
     KBookmark before_trash = m_places->bookmarkForIndex(m_places->index(2, 0));
