@@ -177,7 +177,7 @@ KFileMetaDataProvider::Private::Private(KFileMetaDataProvider* parent) :
     q(parent)
 {
 #ifndef KIO_NO_NEPOMUK
-    m_nepomukActivated = (Nepomuk::ResourceManager::instance()->init() == 0);
+    m_nepomukActivated = Nepomuk::ResourceManager::instance()->initialized();
 #endif
 }
 
@@ -393,8 +393,8 @@ void KFileMetaDataProvider::setItems(const KFileItemList& items)
     if (items.isEmpty()) {
         return;
     }
-    Q_PRIVATE_SLOT(d, void slotDataChangeStarted())
-    Q_PRIVATE_SLOT(d, void slotDataChangeFinished())
+    Q_PRIVATE_SLOT(d,void slotDataChangeStarted())
+    Q_PRIVATE_SLOT(d,void slotDataChangeFinished())
     QList<KUrl> urls;
     foreach (const KFileItem& item, items) {
         const KUrl url = item.nepomukUri();
