@@ -108,8 +108,12 @@ private Q_SLOTS:
     void testOpenAndStop();
     void testBug211472();
     void testRenameCurrentDir();
+    void testRenameCurrentDirOpenUrl();
     void testRedirection();
+    void testListEmptyDirFromCache();
     void testWatchingAfterCopyJob();
+    void testRemoveWatchedDirectory();
+    void testDirPermissionChange();
     void testDeleteCurrentDir(); // must be last!
 
 protected Q_SLOTS: // 'more private than private slots' - i.e. not seen by qtestlib
@@ -118,6 +122,7 @@ protected Q_SLOTS: // 'more private than private slots' - i.e. not seen by qtest
     void slotNewItems2(const KFileItemList&);
     void slotRefreshItems(const QList<QPair<KFileItem, KFileItem> >&);
     void slotRefreshItems2(const QList<QPair<KFileItem, KFileItem> >&);
+    void slotOpenUrlOnRename(const KUrl &);
 
 Q_SIGNALS:
     void refreshItemsReceived();
